@@ -1,12 +1,9 @@
-context("class level lsm_contig_sd metric")
-
 landscapemetrics_class_landscape_value <- lsm_c_contig_sd(landscape)
 
 test_that("lsm_c_contig_sd is typestable", {
-    expect_is(lsm_c_contig_sd(landscape), "tbl_df")
-    expect_is(lsm_c_contig_sd(landscape_stack), "tbl_df")
-    expect_is(lsm_c_contig_sd(landscape_brick), "tbl_df")
-    expect_is(lsm_c_contig_sd(landscape_list), "tbl_df")
+    expect_s3_class(lsm_c_contig_sd(landscape), "tbl_df")
+    expect_s3_class(lsm_c_contig_sd(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_c_contig_sd(landscape_list), "tbl_df")
 })
 
 test_that("lsm_c_contig_sd returns the desired number of columns", {
